==> adv-repulsion-systems_50.0.1_for_1.3.2-joined.jar: mod_shared/immibis/ars/GuiReaktorField.java <==
package immibis.ars;

/* $if jclient$ */

import immibis.ars.projectors.TileProjectorReactor;
import immibis.core.aspects.ClientOnly;
import immibis.core.net.AbstractSyncedContainer;

import java.util.ArrayList;
import java.util.List;

import net.minecraft.client.Minecraft;
import net.minecraft.src.EntityPlayer;
import net.minecraft.src.GuiButton;
import net.minecraft.src.GuiContainer;
import net.minecraft.src.InventoryPlayer;
import org.lwjgl.opengl.GL11;

@ClientOnly
public class GuiReaktorField extends GuiContainer {

	private TileProjectorReactor inventory;
	private String mode;

	public GuiReaktorField(EntityPlayer inventoryplayer, TileProjectorReactor tileEntityReaktorField) {

		super(new ContainerProjektor(inventoryplayer, tileEntityReaktorField));
		inventory = tileEntityReaktorField;

	}

	@SuppressWarnings("unchecked")
	public void initGui() {

		controlList.add(new GuiButton(0, (width / 2) + 35, (height / 2) + 20, 40, 10, "change"));

		super.initGui();
	}
	
	protected void actionPerformed(GuiButton guibutton) {
		((AbstractSyncedContainer)inventorySlots).sendButtonPressed(guibutton.id);
	}

	protected void drawGuiContainerBackgroundLayer(float f, int i, int j) {

		int textur = mc.renderEngine.getTexture("/mffs_grafik/GUIid.png");
		GL11.glColor4f(1.0F, 1.0F, 1.0F, 1.0F);
		mc.renderEngine.bindTexture(textur);
		int w = (width - xSize) / 2;
		int k = (height - ySize) / 2;
		drawTexturedModalRect(w, k, 0, 0, xSize, ySize);

		int i1 = (69 * inventory.getLinkPower()) / inventory.getMaxlinkPower();
		drawTexturedModalRect(w + 93, k + 30, 176, 0, i1 + 1, 69);

	}

	protected void drawGuiContainerForegroundLayer() {

		fontRenderer.drawString("MFFS reactor containment field", 10, 5, 0x404040);
		fontRenderer.drawString("Force power", 10, 30, 0x404040);
		fontRenderer.drawString("available", 22, 40, 0x404040);
		fontRenderer.drawString("Linked to core:", 10, 60, 0x404040);
		fontRenderer.drawString("Linked to reactor: ", 10, 70, 0x404040);
		fontRenderer.drawString("Reactor heat: ", 10, 80, 0x404040);
		fontRenderer.drawString("Water cooling: ", 10, 90, 0x404040);
		fontRenderer.drawString("Frequency card:", 10, 123, 0x404040);

		fontRenderer.drawString((new StringBuilder()).append(" ").append(inventory.getLinkPower()).toString(), 100, 45, 0x404040);
		fontRenderer.drawString((new StringBuilder()).append(" ").append(inventory.isLinkGenerator()).toString(), 120, 60, 0x404040);
		fontRenderer.drawString((new StringBuilder()).append(" ").append(inventory.isIsreaktor()).toString(), 120, 70, 0x404040);
		fontRenderer.drawString((new StringBuilder()).append(" ").append(inventory.getReaktorheat()).toString(), 120, 80, 0x404040);
		fontRenderer.drawString((new StringBuilder()).append(" ").append(inventory.isWatercool()).toString(), 120, 90, 0x404040);

	}

}

/* $endif$ */

==> adv-repulsion-systems_50.2.5_for_1.4.2-joined.jar: mod_shared/immibis/ars/GuiReaktorField.java <==
package immibis.ars;

/* $if jclient$ */

import immibis.ars.projectors.TileProjectorReactor;
import immibis.core.aspects.ClientOnly;
import immibis.core.net.AbstractSyncedContainer;

import net.minecraft.src.EntityPlayer;
import net.minecraft.src.GuiButton;
import net.minecraft.src.GuiContainer;
import org.lwjgl.opengl.GL11;

@ClientOnly
public class GuiReaktorField extends GuiContainer {

	private TileProjectorReactor inventory;
	
	public GuiReaktorField(EntityPlayer inventoryplayer, TileProjectorReactor tileEntityReaktorField) {

		super(new ContainerProjektor(inventoryplayer, tileEntityReaktorField));
		inventory = tileEntityReaktorField;

	}

	@SuppressWarnings("unchecked")
	@Override
	public void initGui() {

		controlList.add(new GuiButton(0, (width / 2) + 35, (height / 2) + 20, 40, 10, "change"));

		super.initGui();
	}
	
	@Override
	protected void actionPerformed(GuiButton guibutton) {
		((AbstractSyncedContainer)inventorySlots).sendButtonPressed(guibutton.id);
	}

	@Override
	protected void drawGuiContainerBackgroundLayer(float f, int i, int j) {

		int textur = mc.renderEngine.getTexture("/immibis/ars/textures/GUIid.png");
		GL11.glColor4f(1.0F, 1.0F, 1.0F, 1.0F);
		mc.renderEngine.bindTexture(textur);
		int w = (width - xSize) / 2;
		int k = (height - ySize) / 2;
		drawTexturedModalRect(w, k, 0, 0, xSize, ySize);

		int i1 = (69 * inventory.getLinkPower()) / inventory.getMaxlinkPower();
		drawTexturedModalRect(w + 93, k + 30, 176, 0, i1 + 1, 69);

	}

	@Override
	/* $if mc < 1.4$
	protected void drawGuiContainerForegroundLayer() {
	$else$ */
	protected void drawGuiContainerForegroundLayer(int par1, int par2) { 
	/* $endif$ */

		fontRenderer.drawString("Reactor containment field", 10, 5, 0x404040);
		fontRenderer.drawString("Force power", 10, 30, 0x404040);
		fontRenderer.drawString("available", 22, 40, 0x404040);
		fontRenderer.drawString("Linked to core:", 10, 60, 0x404040);
		fontRenderer.drawString("Linked to reactor: ", 10, 70, 0x404040);
		fontRenderer.drawString("Reactor heat: ", 10, 80, 0x404040);
		fontRenderer.drawString("Water cooling: ", 10, 90, 0x404040);
		fontRenderer.drawString("Frequency card:", 10, 123, 0x404040);

		fontRenderer.drawString((new StringBuilder()).append(" ").append(inventory.getLinkPower()).toString(), 100, 45, 0x404040);
		fontRenderer.drawString((new StringBuilder()).append(" ").append(inventory.isLinkGenerator()).toString(), 120, 60, 0x404040);
		fontRenderer.drawString((new StringBuilder()).append(" ").append(inventory.isIsreaktor()).toString(), 120, 70, 0x404040);
		fontRenderer.drawString((new StringBuilder()).append(" ").append(inventory.getReaktorheat()).toString(), 120, 80, 0x404040);
		fontRenderer.drawString((new StringBuilder()).append(" ").append(inventory.isWatercool()).toString(), 120, 90, 0x404040);

	}

}

/* $endif$ */
